"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toContainTitle = void 0;
const utils_1 = require("../utils/utils");
/**
 * Use `toContainTitle` function when you want to check that page's title contains the expected title
 *
 * @example
 * ```typescript
 * await expect(page).toContainTitle('Doc');
 *
 * // also you can check text ignoring case sensitive
 * await expect(page).toContainTitle('doc', {ignoreCase: true})
 * ```
 *
 * @param this
 * @param page
 * @param expectedTitle
 * @param options
 * @returns
 */
async function toContainTitle(page, expectedTitle, options) {
    try {
        let actualTitle = await page.title();
        if (options === null || options === void 0 ? void 0 : options.ignoreCase) {
            actualTitle = utils_1.formatText(actualTitle, { ignoreCase: true });
            expectedTitle = utils_1.formatText(expectedTitle, { ignoreCase: true });
        }
        else if (options === null || options === void 0 ? void 0 : options.trim) {
            actualTitle = utils_1.formatText(actualTitle, { trim: true });
        }
        return {
            pass: actualTitle.includes(expectedTitle),
            message: () => utils_1.getErrorMessage(this, 'toContainTitle', expectedTitle, actualTitle),
        };
    }
    catch (error) {
        return {
            pass: false,
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            message: () => error.toString(),
        };
    }
}
exports.toContainTitle = toContainTitle;
